@@ -82,7 +82,9 @@ class PythonLanguageServer(LanguageServer):
 
     @_utils.debounce(LINT_DEBOUNCE_S)
     def lint(self, doc_uri):
-        self.workspace.publish_diagnostics(doc_uri, flatten(self._hook('pyls_lint', doc_uri)))
+        # Since we're debounced, the document may no longer be open
+        if doc_uri in self.workspace.documents:
+            self.workspace.publish_diagnostics(doc_uri, flatten(self._hook('pyls_lint', doc_uri)))
 
     def references(self, doc_uri, position, exclude_declaration):
         return flatten(self._hook(
@@ -147,7 +149,7 @@ class PythonLanguageServer(LanguageServer):
         return self.signature_help(textDocument['uri'], position)
 
     def m_workspace__did_change_configuration(self, settings=None):
-        self.config.update((settings or {}).get('pyls'))
+        self.config.update((settings or {}).get('pyls', {}))
         for doc_uri in self.workspace.documents:
             self.lint(doc_uri)
 
